@@ -41,8 +41,8 @@ Monitor::Monitor(QObject *parent)
     : QObject(parent)
     , m_bus(QDBusConnection::sessionBus())
     , m_filePath(QStringLiteral("Idle"))
-    , m_scheduler(0)
-    , m_fileindexer(0)
+    , m_scheduler(nullptr)
+    , m_fileindexer(nullptr)
     , m_filesIndexed(0)
     , m_remainingTime(QStringLiteral("Estimating"))
 {
@@ -85,7 +85,7 @@ void Monitor::newFile(const QString& filePath)
     }
     Q_EMIT newFileIndexed();
 
-    if (m_filesIndexed % (40 * 5) == 0) {
+    if (m_filesIndexed % (m_scheduler->getBatchSize() * 5) == 0) {
         updateRemainingTime();
     }
 }
@@ -97,7 +97,7 @@ QString Monitor::suspendState() const
 
 void Monitor::toggleSuspendState()
 {
-    Q_ASSERT(m_scheduler != 0);
+    Q_ASSERT(m_scheduler != nullptr);
 
     if (m_indexerState == Baloo::Suspended) {
         m_scheduler->resume();
@@ -126,7 +126,7 @@ void Monitor::balooStarted(const QString& service)
 void Monitor::fetchTotalFiles()
 {
     Baloo::Database *db = Baloo::globalDatabaseInstance();
-    if (db->open(Baloo::Database::OpenDatabase)) {
+    if (db->open(Baloo::Database::ReadOnlyDatabase)) {
         Baloo::Transaction tr(db, Baloo::Transaction::ReadOnly);
         m_totalFiles = tr.size();
         m_filesIndexed = tr.size() - tr.phaseOneSize();
